@@ -1,7 +1,8 @@
-package HTML::FormFu::Constraint::AutoSet;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
+
+package HTML::FormFu::Constraint::AutoSet;
+$HTML::FormFu::Constraint::AutoSet::VERSION = '2.07';
+# ABSTRACT: Set Constraint for Selects / Radiogroups / Checkboxgroups
 
 use Moose;
 extends 'HTML::FormFu::Constraint::Set';
@@ -24,7 +25,8 @@ sub _parse_value {
     }
     else {
         # disabled attributes should be ignored
-        return if ($item->{attributes} and $item->{attributes}->{disabled});
+        return if ( $item->{attributes} and $item->{attributes}->{disabled} );
+
         # anything else is fine
         return $item->{value};
     }
@@ -36,13 +38,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Constraint::AutoSet - Set Constraint for Selects / Radiogroups / Checkboxgroups
 
 =head1 VERSION
 
-version 2.03
+version 2.07
 
 =head1 DESCRIPTION
 
@@ -67,4 +73,15 @@ Carl Franks C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
