@@ -1,5 +1,9 @@
+use strict;
+
 package HTML::FormFu::Element::Submit;
-$HTML::FormFu::Element::Submit::VERSION = '2.01';
+$HTML::FormFu::Element::Submit::VERSION = '2.07';
+# ABSTRACT: Submit button form field
+
 use Moose;
 
 extends 'HTML::FormFu::Element::Button';
@@ -18,10 +22,18 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Submit - Submit button form field
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     $element = $form->element( Submit => 'foo' );
@@ -34,10 +46,10 @@ Submit button form field.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Button>, 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Button>,
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -51,4 +63,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
