@@ -1,5 +1,9 @@
+use strict;
+
 package HTML::FormFu::Element::Text;
-$HTML::FormFu::Element::Text::VERSION = '2.01';
+$HTML::FormFu::Element::Text::VERSION = '2.07';
+# ABSTRACT: Text form field
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -20,10 +24,18 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Text - Text form field
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     my $element = $form->element( Text => 'foo' );
@@ -34,9 +46,9 @@ Text form field.
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>.
 
 L<HTML::FormFu>
@@ -50,4 +62,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
