@@ -1,7 +1,8 @@
-package HTML::FormFu::Element::Textarea;
-
 use strict;
-our $VERSION = '2.03'; # VERSION
+
+package HTML::FormFu::Element::Textarea;
+$HTML::FormFu::Element::Textarea::VERSION = '2.07';
+# ABSTRACT: Textarea form field
 
 use Moose;
 
@@ -12,13 +13,13 @@ with 'HTML::FormFu::Role::Element::Field',
 
 use HTML::FormFu::Util qw( process_attrs );
 
-__PACKAGE__->mk_attr_accessors(qw(
-    autocomplete
-    cols
-    maxlength
-    rows
-    placeholder
-));
+__PACKAGE__->mk_attr_accessors( qw(
+        autocomplete
+        cols
+        maxlength
+        rows
+        placeholder
+) );
 
 after BUILD => sub {
     my $self = shift;
@@ -55,13 +56,17 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Element::Textarea - Textarea form field
 
 =head1 VERSION
 
-version 2.03
+version 2.07
 
 =head1 SYNOPSIS
 
@@ -106,4 +111,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
