@@ -1,5 +1,8 @@
+use strict;
+
 package HTML::FormFu::I18N::bg;
-$HTML::FormFu::I18N::bg::VERSION = '2.01';
+# ABSTRACT: Bulgarian
+$HTML::FormFu::I18N::bg::VERSION = '2.07';
 use utf8;
 
 use Moose;
@@ -75,3 +78,30 @@ our %Lexicon = (
 __PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::I18N::bg - Bulgarian
+
+=head1 VERSION
+
+version 2.07
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
