@@ -1,9 +1,9 @@
-package HTML::FormFu::I18N::ro;
-
-use utf8;
-
 use strict;
-our $VERSION = '2.05'; # VERSION
+
+package HTML::FormFu::I18N::ro;
+# ABSTRACT: Romanian
+$HTML::FormFu::I18N::ro::VERSION = '2.07';
+use utf8;
 
 use Moose;
 extends 'HTML::FormFu::I18N';
@@ -68,3 +68,30 @@ our %Lexicon = (
 __PACKAGE__->meta->make_immutable( inline_constructor => 0 );
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTML::FormFu::I18N::ro - Romanian
+
+=head1 VERSION
+
+version 2.07
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
