@@ -1,16 +1,21 @@
+use strict;
+
 package HTML::FormFu::Inflator::Callback;
-$HTML::FormFu::Inflator::Callback::VERSION = '2.01';
+$HTML::FormFu::Inflator::Callback::VERSION = '2.07';
+# ABSTRACT: Callback inflator
+
 use Moose;
-use MooseX::Attribute::FormFuChained;
+use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Inflator';
 
-has callback => ( is => 'rw', traits => ['FormFuChained'] );
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub inflator {
     my ( $self, $value ) = @_;
 
     my $callback = $self->callback || sub {shift};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     return $callback->($value);
@@ -22,10 +27,18 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Inflator::Callback - Callback inflator
 
+=head1 VERSION
+
+version 2.07
+
 =head1 SYNOPSIS
 
     $field->inflator('Callback')->callback( \&my_callback );
@@ -64,3 +77,16 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
