@@ -1,8 +1,11 @@
+use strict;
+
 package HTML::FormFu::Role::Element::Field;
-$HTML::FormFu::Role::Element::Field::VERSION = '2.01';
+$HTML::FormFu::Role::Element::Field::VERSION = '2.07';
+# ABSTRACT: Role for all form-field elements
+
 use Moose::Role;
 use MooseX::Aliases;
-use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::ContainsElementsSharedWithField',
     'HTML::FormFu::Role::NestedHashUtils',
@@ -21,7 +24,7 @@ use HTML::FormFu::Util qw(
 );
 use Class::MOP::Method;
 use Clone ();
-use List::MoreUtils qw( uniq );
+use List::Util 1.45 qw( uniq );
 use Carp qw( croak carp );
 
 __PACKAGE__->mk_attrs( qw(
@@ -32,28 +35,28 @@ __PACKAGE__->mk_attrs( qw(
         error_container_attributes
 ) );
 
-has _constraints         => ( is => 'rw', traits => ['FormFuChained'] );
-has _filters             => ( is => 'rw', traits => ['FormFuChained'] );
-has _inflators           => ( is => 'rw', traits => ['FormFuChained'] );
-has _deflators           => ( is => 'rw', traits => ['FormFuChained'] );
-has _validators          => ( is => 'rw', traits => ['FormFuChained'] );
-has _transformers        => ( is => 'rw', traits => ['FormFuChained'] );
-has _plugins             => ( is => 'rw', traits => ['FormFuChained'] );
-has _errors              => ( is => 'rw', traits => ['FormFuChained'] );
-has container_tag        => ( is => 'rw', traits => ['FormFuChained'] );
-has field_filename       => ( is => 'rw', traits => ['FormFuChained'] );
-has label_filename       => ( is => 'rw', traits => ['FormFuChained'] );
-has label_tag            => ( is => 'rw', traits => ['FormFuChained'] );
-has retain_default       => ( is => 'rw', traits => ['FormFuChained'] );
-has force_default        => ( is => 'rw', traits => ['FormFuChained'] );
-has javascript           => ( is => 'rw', traits => ['FormFuChained'] );
-has non_param            => ( is => 'rw', traits => ['FormFuChained'] );
-has reverse_single       => ( is => 'rw', traits => ['FormFuChained'] );
-has reverse_multi        => ( is => 'rw', traits => ['FormFuChained'] );
-has multi_value          => ( is => 'rw', traits => ['FormFuChained'] );
-has original_name        => ( is => 'rw', traits => ['FormFuChained'] );
-has original_nested_name => ( is => 'rw', traits => ['FormFuChained'] );
-has default_empty_value  => ( is => 'rw', traits => ['FormFuChained'] );
+has _constraints         => ( is => 'rw', traits => ['Chained'] );
+has _filters             => ( is => 'rw', traits => ['Chained'] );
+has _inflators           => ( is => 'rw', traits => ['Chained'] );
+has _deflators           => ( is => 'rw', traits => ['Chained'] );
+has _validators          => ( is => 'rw', traits => ['Chained'] );
+has _transformers        => ( is => 'rw', traits => ['Chained'] );
+has _plugins             => ( is => 'rw', traits => ['Chained'] );
+has _errors              => ( is => 'rw', traits => ['Chained'] );
+has container_tag        => ( is => 'rw', traits => ['Chained'] );
+has field_filename       => ( is => 'rw', traits => ['Chained'] );
+has label_filename       => ( is => 'rw', traits => ['Chained'] );
+has label_tag            => ( is => 'rw', traits => ['Chained'] );
+has retain_default       => ( is => 'rw', traits => ['Chained'] );
+has force_default        => ( is => 'rw', traits => ['Chained'] );
+has javascript           => ( is => 'rw', traits => ['Chained'] );
+has non_param            => ( is => 'rw', traits => ['Chained'] );
+has reverse_single       => ( is => 'rw', traits => ['Chained'] );
+has reverse_multi        => ( is => 'rw', traits => ['Chained'] );
+has multi_value          => ( is => 'rw', traits => ['Chained'] );
+has original_name        => ( is => 'rw', traits => ['Chained'] );
+has original_nested_name => ( is => 'rw', traits => ['Chained'] );
+has default_empty_value  => ( is => 'rw', traits => ['Chained'] );
 
 __PACKAGE__->mk_output_accessors(qw( comment label value ));
 
@@ -492,22 +495,23 @@ sub process_value {
 around render_data_non_recursive => sub {
     my ( $orig, $self, $args ) = @_;
 
-    my $render = $self->$orig( {
-            nested_name          => xml_escape( $self->nested_name ),
-            comment_attributes   => xml_escape( $self->comment_attributes ),
-            container_attributes => xml_escape( $self->container_attributes ),
-            label_attributes     => xml_escape( $self->label_attributes ),
-            comment              => xml_escape( $self->comment ),
-            label                => xml_escape( $self->label ),
-            field_filename       => $self->field_filename,
-            label_filename       => $self->label_filename,
-            label_tag            => $self->label_tag,
-            container_tag        => $self->container_tag,
-            error_container_tag  => $self->error_container_tag,
-            error_tag            => $self->error_tag,
-            reverse_single       => $self->reverse_single,
-            reverse_multi        => $self->reverse_multi,
-            javascript           => $self->javascript,
+    my $render = $self->$orig(
+        {   nested_name                => xml_escape( $self->nested_name ),
+            comment_attributes         => xml_escape( $self->comment_attributes ),
+            container_attributes       => xml_escape( $self->container_attributes ),
+            error_container_attributes => xml_escape( $self->error_container_attributes ),
+            label_attributes           => xml_escape( $self->label_attributes ),
+            comment                    => xml_escape( $self->comment ),
+            label                      => xml_escape( $self->label ),
+            field_filename             => $self->field_filename,
+            label_filename             => $self->label_filename,
+            label_tag                  => $self->label_tag,
+            container_tag              => $self->container_tag,
+            error_container_tag        => $self->error_container_tag,
+            error_tag                  => $self->error_tag,
+            reverse_single             => $self->reverse_single,
+            reverse_multi              => $self->reverse_multi,
+            javascript                 => $self->javascript,
             $args ? %$args : (),
         } );
 
@@ -542,10 +546,9 @@ sub _render_label {
         $render->{label} = $self->form->localize($label);
     }
 
-    if (    defined $render->{label}
-         && defined $self->auto_label_class
-         && length $self->auto_label_class
-        )
+    if (   defined $render->{label}
+        && defined $self->auto_label_class
+        && length $self->auto_label_class )
     {
         my $form_name
             = defined $self->form->id
@@ -556,10 +559,10 @@ sub _render_label {
             = defined $render->{nested_name}
             ? $render->{nested_name}
             : $EMPTY_STR;
-        
+
         my $type = lc $self->type;
         $type =~ s/:://g;
-        
+
         my %string = (
             f => $form_name,
             n => $field_name,
@@ -568,15 +571,13 @@ sub _render_label {
 
         my $class = $self->auto_label_class;
         $class =~ s/%([fnt])/$string{$1}/g;
-        
-        append_xml_attribute( $render->{label_attributes},
-            'class', $class );
+
+        append_xml_attribute( $render->{label_attributes}, 'class', $class );
     }
 
-    if (    defined $render->{label}
-         && defined $self->auto_container_label_class
-         && length $self->auto_container_label_class
-        )
+    if (   defined $render->{label}
+        && defined $self->auto_container_label_class
+        && length $self->auto_container_label_class )
     {
         my $form_name
             = defined $self->form->id
@@ -587,10 +588,10 @@ sub _render_label {
             = defined $render->{nested_name}
             ? $render->{nested_name}
             : $EMPTY_STR;
-        
+
         my $type = lc $self->type;
         $type =~ s/:://g;
-        
+
         my %string = (
             f => $form_name,
             n => $field_name,
@@ -599,7 +600,7 @@ sub _render_label {
 
         my $class = $self->auto_container_label_class;
         $class =~ s/%([fnt])/$string{$1}/g;
-        
+
         append_xml_attribute( $render->{container_attributes},
             'class', $class );
     }
@@ -617,11 +618,10 @@ sub _render_label {
 
 sub _render_comment_class {
     my ( $self, $render ) = @_;
-    
-    if (    defined $render->{comment}
-         && defined $self->auto_comment_class
-         && length $self->auto_comment_class
-        )
+
+    if (   defined $render->{comment}
+        && defined $self->auto_comment_class
+        && length $self->auto_comment_class )
     {
         my $form_name
             = defined $self->form->id
@@ -632,7 +632,7 @@ sub _render_comment_class {
             = defined $render->{nested_name}
             ? $render->{nested_name}
             : $EMPTY_STR;
-        
+
         my %string = (
             f => $form_name,
             n => $field_name,
@@ -641,14 +641,12 @@ sub _render_comment_class {
         my $class = $self->auto_comment_class;
         $class =~ s/%([fn])/$string{$1}/g;
 
-        append_xml_attribute( $render->{comment_attributes},
-            'class', $class );
+        append_xml_attribute( $render->{comment_attributes}, 'class', $class );
     }
 
-    if (    defined $render->{comment}
-         && defined $self->auto_container_comment_class
-         && length $self->auto_container_comment_class
-        )
+    if (   defined $render->{comment}
+        && defined $self->auto_container_comment_class
+        && length $self->auto_container_comment_class )
     {
         my $form_name
             = defined $self->form->id
@@ -659,7 +657,7 @@ sub _render_comment_class {
             = defined $render->{nested_name}
             ? $render->{nested_name}
             : $EMPTY_STR;
-        
+
         my %string = (
             f => $form_name,
             n => $field_name,
@@ -689,8 +687,8 @@ sub _render_value {
     {
         if ( $self->render_processed_value ) {
             $input
-                = $self->get_nested_hash_value( $form->_processed_params, $name,
-                );
+                = $self->get_nested_hash_value( $form->_processed_params,
+                $name, );
         }
         else {
             $input = $self->get_nested_hash_value( $form->input, $name, );
@@ -737,9 +735,8 @@ sub _render_value {
 sub _render_container_class {
     my ( $self, $render ) = @_;
 
-    if (    defined $self->auto_container_class
-         && length $self->auto_container_class
-        )
+    if ( defined $self->auto_container_class
+        && length $self->auto_container_class )
     {
         my $form_name
             = defined $self->form->id
@@ -750,10 +747,10 @@ sub _render_container_class {
             = defined $render->{nested_name}
             ? $render->{nested_name}
             : $EMPTY_STR;
-        
+
         my $type = lc $self->type;
         $type =~ s/:://g;
-        
+
         my %string = (
             f => $form_name,
             n => $field_name,
@@ -893,6 +890,20 @@ sub _render_error_class {
 
     $render->{errors} = \@errors;
 
+    # auto_error_field_class
+    my $field_class = $self->auto_error_field_class;
+
+    if ( defined $field_class && length $field_class ) {
+        my %string = (
+            f => sub { defined $self->form->id ? $self->form->id : '' },
+            n => sub { defined $render->{name} ? $render->{name} : '' },
+        );
+
+        $field_class =~ s/%([fn])/$string{$1}->()/ge;
+
+        append_xml_attribute( $render->{attributes}, 'class', $field_class );
+    }
+
     my @container_class;
 
     # auto_container_error_class
@@ -900,8 +911,8 @@ sub _render_error_class {
 
     if ( defined $auto_class && length $auto_class ) {
         my %string = (
-            f => sub { defined $self->form->id ? $self->form->id   : '' },
-            n => sub { defined $render->{name} ? $render->{name}   : '' },
+            f => sub { defined $self->form->id ? $self->form->id : '' },
+            n => sub { defined $render->{name} ? $render->{name} : '' },
         );
 
         $auto_class =~ s/%([fn])/$string{$1}->()/ge;
@@ -915,8 +926,8 @@ sub _render_error_class {
     if ( defined $item_class && length $item_class ) {
         for my $error (@errors) {
             my %string = (
-                f => sub { defined $self->form->id ? $self->form->id   : '' },
-                n => sub { defined $render->{name} ? $render->{name}   : '' },
+                f => sub { defined $self->form->id ? $self->form->id : '' },
+                n => sub { defined $render->{name} ? $render->{name} : '' },
                 s => sub { $error->{stage} },
                 t => sub { lc $error->{type} },
             );
@@ -928,9 +939,8 @@ sub _render_error_class {
         }
     }
 
-    map {
-        append_xml_attribute( $render->{container_attributes}, 'class', $_ )
-    } uniq @container_class;
+    map { append_xml_attribute( $render->{container_attributes}, 'class', $_ ) }
+        uniq @container_class;
 
     my @error_container_class;
 
@@ -941,8 +951,8 @@ sub _render_error_class {
 
         if ( defined $auto_class && length $auto_class ) {
             my %string = (
-                f => sub { defined $self->form->id ? $self->form->id   : '' },
-                n => sub { defined $render->{name} ? $render->{name}   : '' },
+                f => sub { defined $self->form->id ? $self->form->id : '' },
+                n => sub { defined $render->{name} ? $render->{name} : '' },
             );
 
             $auto_class =~ s/%([fn])/$string{$1}->()/ge;
@@ -956,8 +966,8 @@ sub _render_error_class {
         if ( defined $item_class && length $item_class ) {
             for my $error (@errors) {
                 my %string = (
-                    f => sub { defined $self->form->id ? $self->form->id   : '' },
-                    n => sub { defined $render->{name} ? $render->{name}   : '' },
+                    f => sub { defined $self->form->id ? $self->form->id : '' },
+                    n => sub { defined $render->{name} ? $render->{name} : '' },
                     s => sub { $error->{stage} },
                     t => sub { lc $error->{type} },
                 );
@@ -969,8 +979,9 @@ sub _render_error_class {
             }
         }
 
-         map {
-            append_xml_attribute( $render->{error_container_attributes}, 'class', $_ )
+        map {
+            append_xml_attribute( $render->{error_container_attributes},
+                'class', $_ )
         } uniq @error_container_class;
     }
 
@@ -982,7 +993,7 @@ sub render_label {
 
     my $render = $self->render_data;
 
-    return $self->_string_label( $render );
+    return $self->_string_label($render);
 }
 
 sub render_field {
@@ -990,7 +1001,7 @@ sub render_field {
 
     my $render = $self->render_data;
 
-    return $self->_string_field( $render );
+    return $self->_string_field($render);
 }
 
 sub _string_field_start {
@@ -1010,7 +1021,7 @@ sub _string_field_start {
         $html .= sprintf "\n%s", $self->_string_label($render);
     }
 
-    $html .= $self->_string_errors( $render );
+    $html .= $self->_string_errors($render);
 
     if (   defined $render->{label}
         && $render->{label_tag} ne 'legend'
@@ -1134,10 +1145,18 @@ around clone => sub {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 HTML::FormFu::Role::Element::Field - Role for all form-field elements
 
+=head1 VERSION
+
+version 2.07
+
 =head1 DESCRIPTION
 
 Base-class for all form-field elements.
@@ -1154,16 +1173,16 @@ Is an L<output accessor|HTML::FormFu/OUTPUT ACCESSORS>.
 
 For most fields, L</value> is an alias for L</default>.
 
-For the L<HTML::FormFu::Element::Checkbox> and 
-L<HTML::FormFu::Element::Radio> elements, L</value> sets what the value of 
-the field will be if it is checked or selected. If the L</default> is the 
-same as the L</value>, then the field will be checked or selected when 
+For the L<HTML::FormFu::Element::Checkbox> and
+L<HTML::FormFu::Element::Radio> elements, L</value> sets what the value of
+the field will be if it is checked or selected. If the L</default> is the
+same as the L</value>, then the field will be checked or selected when
 rendered.
 
-For the L<HTML::FormFu::Element::Radiogroup> and 
-L<HTML::FormFu::Element::Select> elements, the L</value> is ignored: 
-L<values|HTML::FormFu::Role::Element::Group/values> or 
-L<options|HTML::FormFu::Role::Element::Group/options> provides the equivalent 
+For the L<HTML::FormFu::Element::Radiogroup> and
+L<HTML::FormFu::Element::Select> elements, the L</value> is ignored:
+L<values|HTML::FormFu::Role::Element::Group/values> or
+L<options|HTML::FormFu::Role::Element::Group/options> provides the equivalent
 function.
 
 Is an L<output accessor|HTML::FormFu/OUTPUT ACCESSORS>.
@@ -1174,10 +1193,10 @@ Arguments: bool
 
 Default Value: false
 
-If true, values for this field are never returned by L<HTML::FormFu/params>, 
+If true, values for this field are never returned by L<HTML::FormFu/params>,
 L<HTML::FormFu/param> and L<HTML::FormFu/valid>.
 
-This is useful for Submit buttons, when you only use its value as an 
+This is useful for Submit buttons, when you only use its value as an
 L<indicator|HTML::FormFu/indicator>
 
 =head2 placeholder
@@ -1190,14 +1209,14 @@ Is an L<output accessor|HTML::FormFu/OUTPUT ACCESSORS>.
 
 Arguments: [$javascript]
 
-If set, the contents will be rendered within a C<script> tag, within the 
+If set, the contents will be rendered within a C<script> tag, within the
 field's container.
 
 =head2 retain_default
 
-If L</retain_default> is true and the form was submitted, but the field 
-didn't have a value submitted, then when the form is redisplayed to the user 
-the field will have its value set to its default value, rather than the 
+If L</retain_default> is true and the form was submitted, but the field
+didn't have a value submitted, then when the form is redisplayed to the user
+the field will have its value set to its default value, rather than the
 usual behaviour of having an empty value.
 
 Default Value: C<false>
@@ -1495,7 +1514,7 @@ wrapped around all of the field error messages.
 
     # Example - this would wrap each individual error in a 'li' tag,
     # with a single 'ul' tag wrapped around all the errors.
-    
+
     element:
       name: foo
       error_container_tag: ul
@@ -1503,6 +1522,12 @@ wrapped around all of the field error messages.
 
 Is an L<inheriting accessor|HTML::FormFu/INHERITING ACCESSORS>.
 
+=head3 error_container_attributes
+
+Set attributes on the container-tag, if L</error_container_tag> is set.
+
+Is an L<attribute accessor|HTML::FormFu/ATTRIBUTE ACCESSOR>.
+
 =head3 auto_error_container_class
 
 Add a class-name to the error container.
@@ -1531,7 +1556,6 @@ Defaults to C<span>.
 
 Is an L<inheriting accessor|HTML::FormFu/INHERITING ACCESSORS>.
 
-
 =head3 auto_error_message
 
 Default Value: 'form_%s_%t'
@@ -1557,6 +1581,12 @@ Set attributes on the tag of each error message.
 
 Is an L<attribute accessor|HTML::FormFu/ATTRIBUTE ACCESSOR>.
 
+=head3 auto_error_field_class
+
+Upon error, add a class name firectly to the field tag (e.g. C<input>, C<select> tag).
+
+Supports L<substitutions|HTML::FormFu/ATTRIBUTE SUBSTITUTIONS>: C<%f>, C<%n>.
+
 =head3 auto_error_class
 
 Default Value: 'error_%s_%t'
@@ -1628,7 +1658,7 @@ Remove the comment - this will now never be rendered.
           - label_text
           - field
       - javascript
-    
+
     # prettified example of rendered markup
     <div>
         <span>This field is required.</span>
@@ -1646,14 +1676,14 @@ extra tag.
     layout:
       - errors
       - label_text
-      - 
+      -
         div:
           attributes:
             class: xxx
           content: field
       - comment
       - javascript
-    
+
     # prettified example of rendered markup
     <div>
         <span>This field is required.</span>
@@ -1716,7 +1746,7 @@ See L<LABEL|/LABEL> to customize the tag and attributes.
 
 =item label_text
 
-Renders the element L<label|/label> text, without the usual 
+Renders the element L<label|/label> text, without the usual
 L<label_tag|/label_tag>.
 
 =item field
@@ -1737,7 +1767,7 @@ Renders a C<script> tag containing any L<javascript|/javascript>.
 
 =head2 multi_layout
 
-Specify the order that each sub-part of each element within a 
+Specify the order that each sub-part of each element within a
 L<HTML::FormFu::Element::Multi|HTML::FormFu::Element::Multi> should
 appear in the rendered markup.
 
@@ -1747,7 +1777,7 @@ appear in the rendered markup.
         'field',
     ] );
 
-Example: Swap the label/field order. This is equivalent to the 
+Example: Swap the label/field order. This is equivalent to the
 now-deprecated L<reverse_multi|/reverse_multi> method.
 
     # YAML config
@@ -1767,8 +1797,8 @@ The following elements override the default C<multi_layout> value:
 
 =head2 field_filename
 
-The template filename to be used for just the form field - not including the 
-display of any container, label, errors, etc. 
+The template filename to be used for just the form field - not including the
+display of any container, label, errors, etc.
 
 Must be set by more specific field classes.
 
@@ -1868,10 +1898,10 @@ See L<layout_errors_filename|/layout_errors_filename> instead.
 
 =head1 SEE ALSO
 
-Base-class for L<HTML::FormFu::Role::Element::Group>, 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Element::Multi>, 
-L<HTML::FormFu::Element::ContentButton>, 
+Base-class for L<HTML::FormFu::Role::Element::Group>,
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Element::Multi>,
+L<HTML::FormFu::Element::ContentButton>,
 L<HTML::FormFu::Element::Textarea>.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Element>
@@ -1887,4 +1917,15 @@ Carl Franks, C<cfranks@cpan.org>
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Carl Franks <cpan@fireartist.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Carl Franks.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
